# Django SMS

[![PyPI](https://img.shields.io/pypi/v/django-sms?color=ee5042&logo=python&logoColor=ffffff&style=for-the-badge)](https://pypi.org/project/django-sms/)
[![GitHub Workflow Status](https://img.shields.io/github/workflow/status/roaldnefs/django-sms/tests?color=ee5042&label=CI&logo=github&style=for-the-badge)](https://github.com/roaldnefs/django-sms/actions)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/django-sms?color=ee5042&logo=python&logoColor=white&style=for-the-badge)](https://pypi.org/project/django-sms/)
[![PyPI - Django Version](https://img.shields.io/pypi/djversions/django-sms?color=ee5042&logo=django&logoColor=ffffff&style=for-the-badge)](https://pypi.org/project/django-sms/)

**django-sms** is a Django app for sending SMS with interchangeable backends.
